pub struct SecurityCenter { /* private fields */ }Expand description
Implements a client for the Security Command Center API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = SecurityCenter::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_attack_paths()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
V2 APIs for Security Center service.
Configuration
To configure SecurityCenter use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://securitycenter.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SecurityCenter holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SecurityCenter in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SecurityCenter
impl SecurityCenter
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SecurityCenter.
let client = SecurityCenter::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SecurityCenter + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SecurityCenter + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn batch_create_resource_value_configs(
&self,
) -> BatchCreateResourceValueConfigs
pub fn batch_create_resource_value_configs( &self, ) -> BatchCreateResourceValueConfigs
Creates a ResourceValueConfig for an organization. Maps user’s tags to difference resource values for use by the attack path simulation.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.batch_create_resource_value_configs()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn bulk_mute_findings(&self) -> BulkMuteFindings
pub fn bulk_mute_findings(&self) -> BulkMuteFindings
Kicks off an LRO to bulk mute findings for a parent based on a filter. If no location is specified, findings are muted in global. The parent can be either an organization, folder, or project. The findings matched by the filter will be muted after the LRO is done.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.bulk_mute_findings()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_big_query_export(&self) -> CreateBigQueryExport
pub fn create_big_query_export(&self) -> CreateBigQueryExport
Creates a BigQuery export.
Example
use google_cloud_securitycenter_v2::model::BigQueryExport;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let response = client.create_big_query_export()
.set_parent(parent)
.set_big_query_export(
BigQueryExport::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_finding(&self) -> CreateFinding
pub fn create_finding(&self) -> CreateFinding
Creates a finding in a location. The corresponding source must exist for finding creation to succeed.
Example
use google_cloud_securitycenter_v2::model::Finding;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let response = client.create_finding()
.set_parent(parent)
.set_finding_id("finding_id_value")
.set_finding(
Finding::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_mute_config(&self) -> CreateMuteConfig
pub fn create_mute_config(&self) -> CreateMuteConfig
Creates a mute config.
Example
use google_cloud_securitycenter_v2::model::MuteConfig;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let response = client.create_mute_config()
.set_parent(parent)
.set_mute_config(
MuteConfig::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_notification_config(&self) -> CreateNotificationConfig
pub fn create_notification_config(&self) -> CreateNotificationConfig
Creates a notification config.
Example
use google_cloud_securitycenter_v2::model::NotificationConfig;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let response = client.create_notification_config()
.set_parent(parent)
.set_notification_config(
NotificationConfig::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_source(&self) -> CreateSource
pub fn create_source(&self) -> CreateSource
Creates a source.
Example
use google_cloud_securitycenter_v2::model::Source;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let response = client.create_source()
.set_parent(parent)
.set_source(
Source::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_big_query_export(&self) -> DeleteBigQueryExport
pub fn delete_big_query_export(&self) -> DeleteBigQueryExport
Deletes an existing BigQuery export.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
client.delete_big_query_export()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn delete_mute_config(&self) -> DeleteMuteConfig
pub fn delete_mute_config(&self) -> DeleteMuteConfig
Deletes an existing mute config. If no location is specified, default is global.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
client.delete_mute_config()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn delete_notification_config(&self) -> DeleteNotificationConfig
pub fn delete_notification_config(&self) -> DeleteNotificationConfig
Deletes a notification config.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
client.delete_notification_config()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn delete_resource_value_config(&self) -> DeleteResourceValueConfig
pub fn delete_resource_value_config(&self) -> DeleteResourceValueConfig
Deletes a ResourceValueConfig.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
client.delete_resource_value_config()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn get_big_query_export(&self) -> GetBigQueryExport
pub fn get_big_query_export(&self) -> GetBigQueryExport
Gets a BigQuery export.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.get_big_query_export()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_simulation(&self) -> GetSimulation
pub fn get_simulation(&self) -> GetSimulation
Get the simulation by name or the latest simulation for the given organization.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.get_simulation()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_valued_resource(&self) -> GetValuedResource
pub fn get_valued_resource(&self) -> GetValuedResource
Get the valued resource by name
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.get_valued_resource()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy on the specified Source.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_mute_config(&self) -> GetMuteConfig
pub fn get_mute_config(&self) -> GetMuteConfig
Gets a mute config. If no location is specified, default is global.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.get_mute_config()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_notification_config(&self) -> GetNotificationConfig
pub fn get_notification_config(&self) -> GetNotificationConfig
Gets a notification config.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.get_notification_config()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_resource_value_config(&self) -> GetResourceValueConfig
pub fn get_resource_value_config(&self) -> GetResourceValueConfig
Gets a ResourceValueConfig.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.get_resource_value_config()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_source(&self) -> GetSource
pub fn get_source(&self) -> GetSource
Gets a source.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.get_source()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn group_findings(&self) -> GroupFindings
pub fn group_findings(&self) -> GroupFindings
Filters an organization or source’s findings and groups them by their specified properties in a location. If no location is specified, findings are assumed to be in global
To group across all sources provide a - as the source id.
The following list shows some examples:
/v2/organizations/{organization_id}/sources/-/findings
/v2/organizations/{organization_id}/sources/-/locations/{location_id}/findings
/v2/folders/{folder_id}/sources/-/findings/v2/folders/{folder_id}/sources/-/locations/{location_id}/findings/v2/projects/{project_id}/sources/-/findings/v2/projects/{project_id}/sources/-/locations/{location_id}/findings
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let mut list = client.group_findings()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_attack_paths(&self) -> ListAttackPaths
pub fn list_attack_paths(&self) -> ListAttackPaths
Lists the attack paths for a set of simulation results or valued resources and filter.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let mut list = client.list_attack_paths()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_big_query_exports(&self) -> ListBigQueryExports
pub fn list_big_query_exports(&self) -> ListBigQueryExports
Lists BigQuery exports. Note that when requesting BigQuery exports at a given level all exports under that level are also returned e.g. if requesting BigQuery exports under a folder, then all BigQuery exports immediately under the folder plus the ones created under the projects within the folder are returned.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let mut list = client.list_big_query_exports()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_findings(&self) -> ListFindings
pub fn list_findings(&self) -> ListFindings
Lists an organization or source’s findings.
To list across all sources for a given location provide a - as the source
id. If no location is specified, finding are assumed to be in global.
The following list shows some examples:
/v2/organizations/{organization_id}/sources/-/findings
/v2/organizations/{organization_id}/sources/-/locations/{location_id}/findings
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let mut list = client.list_findings()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_mute_configs(&self) -> ListMuteConfigs
pub fn list_mute_configs(&self) -> ListMuteConfigs
Lists mute configs. If no location is specified, default is global.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let mut list = client.list_mute_configs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_notification_configs(&self) -> ListNotificationConfigs
pub fn list_notification_configs(&self) -> ListNotificationConfigs
Lists notification configs.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let mut list = client.list_notification_configs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_resource_value_configs(&self) -> ListResourceValueConfigs
pub fn list_resource_value_configs(&self) -> ListResourceValueConfigs
Lists all ResourceValueConfigs.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let mut list = client.list_resource_value_configs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_sources(&self) -> ListSources
pub fn list_sources(&self) -> ListSources
Lists all sources belonging to an organization.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let mut list = client.list_sources()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_valued_resources(&self) -> ListValuedResources
pub fn list_valued_resources(&self) -> ListValuedResources
Lists the valued resources for a set of simulation results and filter.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, parent: &str
) -> Result<()> {
let mut list = client.list_valued_resources()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn set_finding_state(&self) -> SetFindingState
pub fn set_finding_state(&self) -> SetFindingState
Updates the state of a finding. If no location is specified, finding is assumed to be in global
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.set_finding_state()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified Source.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_mute(&self) -> SetMute
pub fn set_mute(&self) -> SetMute
Updates the mute state of a finding. If no location is specified, finding is assumed to be in global
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.set_mute()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns the permissions that a caller has on the specified source.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_big_query_export(&self) -> UpdateBigQueryExport
pub fn update_big_query_export(&self) -> UpdateBigQueryExport
Updates a BigQuery export.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::BigQueryExport;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_big_query_export()
.set_big_query_export(
BigQueryExport::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_external_system(&self) -> UpdateExternalSystem
pub fn update_external_system(&self) -> UpdateExternalSystem
Updates external system. This is for a given finding. If no location is specified, finding is assumed to be in global
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::ExternalSystem;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_external_system()
.set_external_system(
ExternalSystem::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_finding(&self) -> UpdateFinding
pub fn update_finding(&self) -> UpdateFinding
Creates or updates a finding. If no location is specified, finding is assumed to be in global. The corresponding source must exist for a finding creation to succeed.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::Finding;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_finding()
.set_finding(
Finding::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_mute_config(&self) -> UpdateMuteConfig
pub fn update_mute_config(&self) -> UpdateMuteConfig
Updates a mute config. If no location is specified, default is global.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::MuteConfig;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_mute_config()
.set_mute_config(
MuteConfig::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_notification_config(&self) -> UpdateNotificationConfig
pub fn update_notification_config(&self) -> UpdateNotificationConfig
Updates a notification config. The following update fields are allowed: description, pubsub_topic, streaming_config.filter
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::NotificationConfig;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_notification_config()
.set_notification_config(
NotificationConfig::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_resource_value_config(&self) -> UpdateResourceValueConfig
pub fn update_resource_value_config(&self) -> UpdateResourceValueConfig
Updates an existing ResourceValueConfigs with new rules.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::ResourceValueConfig;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_resource_value_config()
.set_resource_value_config(
ResourceValueConfig::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_security_marks(&self) -> UpdateSecurityMarks
pub fn update_security_marks(&self) -> UpdateSecurityMarks
Updates security marks. For Finding Security marks, if no location is specified, finding is assumed to be in global. Assets Security Marks can only be accessed through global endpoint.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::SecurityMarks;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_security_marks()
.set_security_marks(
SecurityMarks::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_source(&self) -> UpdateSource
pub fn update_source(&self) -> UpdateSource
Updates a source.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_securitycenter_v2::model::Source;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter, name: &str
) -> Result<()> {
let response = client.update_source()
.set_source(
Source::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_securitycenter_v2::Result;
async fn sample(
client: &SecurityCenter
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for SecurityCenter
impl Clone for SecurityCenter
Sourcefn clone(&self) -> SecurityCenter
fn clone(&self) -> SecurityCenter
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more