#[non_exhaustive]pub struct Object {
pub group: String,
pub kind: String,
pub ns: String,
pub name: String,
pub containers: Vec<Container>,
/* private fields */
}Expand description
Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group: StringKubernetes object group, such as “policy.k8s.io/v1”.
kind: StringKubernetes object kind, such as “Namespace”.
ns: StringKubernetes object namespace. Must be a valid DNS label. Named “ns” to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/docs/tasks/administer-cluster/namespaces/.
name: StringKubernetes object name. For details see https://kubernetes.io/docs/concepts/overview/working-with-objects/names/.
containers: Vec<Container>Pod containers associated with this finding, if any.
Implementations
Sourceimpl Object
impl Object
Sourcepub fn set_containers<T, V>(self, v: T) -> Self
pub fn set_containers<T, V>(self, v: T) -> Self
Sets the value of containers.
Example
ⓘ
use google_cloud_securitycenter_v2::model::Container;
let x = Object::new()
.set_containers([
Container::default()/* use setters */,
Container::default()/* use (different) setters */,
]);Trait Implementations
impl StructuralPartialEq for Object