#[non_exhaustive]pub struct AdaptiveProtection {
pub confidence: f64,
/* private fields */
}Expand description
Information about Google Cloud Armor Adaptive Protection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.confidence: f64A score of 0 means that there is low confidence that the detected event is an actual attack. A score of 1 means that there is high confidence that the detected event is an attack. See the Adaptive Protection documentation for further explanation.
Implementations
Sourceimpl AdaptiveProtection
impl AdaptiveProtection