#[non_exhaustive]pub struct Agent {
pub id: String,
pub display_name: String,
/* private fields */
}Expand description
Represents a monitored AI Agent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringIdentifier of the agent.
display_name: StringThe user friendly name of the specific agent instance where the finding was detected, for example, “Banking Agent”.
Implementations