#[non_exhaustive]pub struct AgentAnomaly {
pub confidence_score: f64,
pub detector_references: Vec<DetectorReference>,
pub invocation_references: Vec<InvocationReference>,
/* private fields */
}Expand description
Represents details about an anomaly detected in an AI agent’s behavior.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.confidence_score: f64The overall confidence score indicating the likelihood that this session contains a true anomaly. The score ranges from 0.0 to 1.0, where 1.0 signifies 100% confidence in the presence of an anomaly and 0.0 signifies 0% confidence.
detector_references: Vec<DetectorReference>The list of references to specific detectors that identified anomalies within this session.
invocation_references: Vec<InvocationReference>References to the OpenTelemetry invocations.
Implementations
Sourceimpl AgentAnomaly
impl AgentAnomaly
Sourcepub fn set_confidence_score<T: Into<f64>>(self, v: T) -> Self
pub fn set_confidence_score<T: Into<f64>>(self, v: T) -> Self
Sets the value of confidence_score.
Example
ⓘ
let x = AgentAnomaly::new().set_confidence_score(42.0);Sourcepub fn set_detector_references<T, V>(self, v: T) -> Self
pub fn set_detector_references<T, V>(self, v: T) -> Self
Sets the value of detector_references.
Example
ⓘ
use google_cloud_securitycenter_v2::model::DetectorReference;
let x = AgentAnomaly::new()
.set_detector_references([
DetectorReference::default()/* use setters */,
DetectorReference::default()/* use (different) setters */,
]);Sourcepub fn set_invocation_references<T, V>(self, v: T) -> Self
pub fn set_invocation_references<T, V>(self, v: T) -> Self
Sets the value of invocation_references.
Example
ⓘ
use google_cloud_securitycenter_v2::model::InvocationReference;
let x = AgentAnomaly::new()
.set_invocation_references([
InvocationReference::default()/* use setters */,
InvocationReference::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for AgentAnomaly
impl Clone for AgentAnomaly
Sourcefn clone(&self) -> AgentAnomaly
fn clone(&self) -> AgentAnomaly
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentAnomaly
impl Debug for AgentAnomaly
Sourceimpl Default for AgentAnomaly
impl Default for AgentAnomaly
Sourcefn default() -> AgentAnomaly
fn default() -> AgentAnomaly
Returns the “default value” for a type. Read more
Sourceimpl Message for AgentAnomaly
impl Message for AgentAnomaly
Sourceimpl PartialEq for AgentAnomaly
impl PartialEq for AgentAnomaly
impl StructuralPartialEq for AgentAnomaly