#[non_exhaustive]pub struct BigQueryExport {
pub name: String,
pub description: String,
pub filter: String,
pub dataset: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub most_recent_editor: String,
pub principal: String,
/* private fields */
}Expand description
Configures how to deliver Findings to BigQuery Instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The relative resource name of this export. See: https://cloud.google.com/apis/design/resource_names#relative_resource_name. The following list shows some examples:
organizations/{organization_id}/locations/{location_id}/bigQueryExports/{export_id}
folders/{folder_id}/locations/{location_id}/bigQueryExports/{export_id}
projects/{project_id}/locations/{location_id}/bigQueryExports/{export_id}
This field is provided in responses, and is ignored when provided in create requests.
description: StringThe description of the export (max of 1024 characters).
filter: StringExpression that defines the filter to apply across create/update events
of findings. The expression is a list of zero or more restrictions combined
via logical operators AND and OR. Parentheses are supported, and OR
has higher precedence than AND.
Restrictions have the form <field> <operator> <value> and may have a
- character in front of them to indicate negation. The fields map to
those defined in the corresponding resource.
The supported operators are:
=for all value types.>,<,>=,<=for integer values.:, meaning substring matching, for strings.
The supported value types are:
- string literals in quotes.
- integer literals without quotes.
- boolean literals
trueandfalsewithout quotes.
dataset: StringThe dataset to write findings’ updates to. Its format is “projects/[project_id]/datasets/[bigquery_dataset_id]”. BigQuery dataset unique ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_).
create_time: Option<Timestamp>Output only. The time at which the BigQuery export was created. This field is set by the server and will be ignored if provided on export on creation.
update_time: Option<Timestamp>Output only. The most recent time at which the BigQuery export was updated. This field is set by the server and will be ignored if provided on export creation or update.
most_recent_editor: StringOutput only. Email address of the user who last edited the BigQuery export. This field is set by the server and will be ignored if provided on export creation or update.
principal: StringOutput only. The service account that needs permission to create table and upload data to the BigQuery dataset.
Implementations
Sourceimpl BigQueryExport
impl BigQueryExport
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_dataset<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = BigQueryExport::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = BigQueryExport::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = BigQueryExport::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = BigQueryExport::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = BigQueryExport::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = BigQueryExport::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_most_recent_editor<T: Into<String>>(self, v: T) -> Self
pub fn set_most_recent_editor<T: Into<String>>(self, v: T) -> Self
Sets the value of most_recent_editor.
Example
let x = BigQueryExport::new().set_most_recent_editor("example");Trait Implementations
Sourceimpl Clone for BigQueryExport
impl Clone for BigQueryExport
Sourcefn clone(&self) -> BigQueryExport
fn clone(&self) -> BigQueryExport
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BigQueryExport
impl Debug for BigQueryExport
Sourceimpl Default for BigQueryExport
impl Default for BigQueryExport
Sourcefn default() -> BigQueryExport
fn default() -> BigQueryExport
Sourceimpl Message for BigQueryExport
impl Message for BigQueryExport
Sourceimpl PartialEq for BigQueryExport
impl PartialEq for BigQueryExport
impl StructuralPartialEq for BigQueryExport