#[non_exhaustive]pub struct CloudArmor {
pub security_policy: Option<SecurityPolicy>,
pub requests: Option<Requests>,
pub adaptive_protection: Option<AdaptiveProtection>,
pub attack: Option<Attack>,
pub threat_vector: String,
pub duration: Option<Duration>,
/* private fields */
}Expand description
Fields related to Google Cloud Armor findings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.security_policy: Option<SecurityPolicy>Information about the Google Cloud Armor security policy relevant to the finding.
requests: Option<Requests>Information about incoming requests evaluated by Google Cloud Armor security policies.
adaptive_protection: Option<AdaptiveProtection>Information about potential Layer 7 DDoS attacks identified by Google Cloud Armor Adaptive Protection.
attack: Option<Attack>Information about DDoS attack volume and classification.
threat_vector: StringDistinguish between volumetric & protocol DDoS attack and application layer attacks. For example, “L3_4” for Layer 3 and Layer 4 DDoS attacks, or “L_7” for Layer 7 DDoS attacks.
duration: Option<Duration>Duration of attack from the start until the current moment (updated every 5 minutes).
Implementations
Sourceimpl CloudArmor
impl CloudArmor
Sourcepub fn set_security_policy<T>(self, v: T) -> Selfwhere
T: Into<SecurityPolicy>,
pub fn set_security_policy<T>(self, v: T) -> Selfwhere
T: Into<SecurityPolicy>,
Sets the value of security_policy.
Example
use google_cloud_securitycenter_v2::model::SecurityPolicy;
let x = CloudArmor::new().set_security_policy(SecurityPolicy::default()/* use setters */);Sourcepub fn set_or_clear_security_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityPolicy>,
pub fn set_or_clear_security_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityPolicy>,
Sets or clears the value of security_policy.
Example
use google_cloud_securitycenter_v2::model::SecurityPolicy;
let x = CloudArmor::new().set_or_clear_security_policy(Some(SecurityPolicy::default()/* use setters */));
let x = CloudArmor::new().set_or_clear_security_policy(None::<SecurityPolicy>);Sourcepub fn set_requests<T>(self, v: T) -> Self
pub fn set_requests<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_requests<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_requests<T>(self, v: Option<T>) -> Self
Sourcepub fn set_adaptive_protection<T>(self, v: T) -> Selfwhere
T: Into<AdaptiveProtection>,
pub fn set_adaptive_protection<T>(self, v: T) -> Selfwhere
T: Into<AdaptiveProtection>,
Sets the value of adaptive_protection.
Example
use google_cloud_securitycenter_v2::model::AdaptiveProtection;
let x = CloudArmor::new().set_adaptive_protection(AdaptiveProtection::default()/* use setters */);Sourcepub fn set_or_clear_adaptive_protection<T>(self, v: Option<T>) -> Selfwhere
T: Into<AdaptiveProtection>,
pub fn set_or_clear_adaptive_protection<T>(self, v: Option<T>) -> Selfwhere
T: Into<AdaptiveProtection>,
Sets or clears the value of adaptive_protection.
Example
use google_cloud_securitycenter_v2::model::AdaptiveProtection;
let x = CloudArmor::new().set_or_clear_adaptive_protection(Some(AdaptiveProtection::default()/* use setters */));
let x = CloudArmor::new().set_or_clear_adaptive_protection(None::<AdaptiveProtection>);Sourcepub fn set_attack<T>(self, v: T) -> Self
pub fn set_attack<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_attack<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_attack<T>(self, v: Option<T>) -> Self
Sourcepub fn set_threat_vector<T: Into<String>>(self, v: T) -> Self
pub fn set_threat_vector<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_duration<T>(self, v: T) -> Self
pub fn set_duration<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self