#[non_exhaustive]pub struct Database {
pub name: String,
pub display_name: String,
pub user_name: String,
pub query: String,
pub grantees: Vec<String>,
pub version: String,
/* private fields */
}Expand description
Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringSome database resources may not have the full resource name populated because these resource types are not yet supported by Cloud Asset Inventory (e.g. Cloud SQL databases). In these cases only the display name will be provided. The full resource name of the database that the user connected to, if it is supported by Cloud Asset Inventory.
display_name: StringThe human-readable name of the database that the user connected to.
user_name: StringThe username used to connect to the database. The username might not be an IAM principal and does not have a set format.
query: StringThe SQL statement that is associated with the database access.
grantees: Vec<String>The target usernames, roles, or groups of an SQL privilege grant, which is not an IAM policy change.
version: StringThe version of the database, for example, POSTGRES_14. See the complete list.
Implementations
Sourceimpl Database
impl Database