DetectorReference

Struct DetectorReference 

#[non_exhaustive]
pub struct DetectorReference { pub severity: Severity, pub detector_id: String, pub display_name: String, pub explanation: String, pub recommendation: String, /* private fields */ }
Represents a reference to a specific anomaly detector.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
severity: Severity

The severity of the detector.

detector_id: String

The unique identifier of the detector.

display_name: String

A human readable name for the detector, providing context on its purpose. For example, “ASI02: Tool Misuse”, or “Excessive API Calls”.

explanation: String

A detailed explanation generated by an LLM or the detector itself, describing why this specific anomaly was flagged. This provides rationale and context for the detection.

recommendation: String

Recommended steps or actions to remediate or investigate the anomaly flagged by this detector. These could include configuration changes, code adjustments, or further diagnostic procedures.

Implementations

Source

impl DetectorReference

pub fn new() -> Self

Creates a new default instance.

pub fn set_severity<T: Into<Severity>>(self, v: T) -> Self

Sets the value of severity.

Example
use google_cloud_securitycenter_v2::model::detector_reference::Severity;
let x0 = DetectorReference::new().set_severity(Severity::Critical);
let x1 = DetectorReference::new().set_severity(Severity::High);
let x2 = DetectorReference::new().set_severity(Severity::Medium);
pub fn set_detector_id<T: Into<String>>(self, v: T) -> Self

Sets the value of detector_id.

Example
let x = DetectorReference::new().set_detector_id("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = DetectorReference::new().set_display_name("example");
pub fn set_explanation<T: Into<String>>(self, v: T) -> Self

Sets the value of explanation.

Example
let x = DetectorReference::new().set_explanation("example");
pub fn set_recommendation<T: Into<String>>(self, v: T) -> Self

Sets the value of recommendation.

Example
let x = DetectorReference::new().set_recommendation("example");