#[non_exhaustive]pub struct Kubernetes {
pub pods: Vec<Pod>,
pub nodes: Vec<Node>,
pub node_pools: Vec<NodePool>,
pub roles: Vec<Role>,
pub bindings: Vec<Binding>,
pub access_reviews: Vec<AccessReview>,
pub objects: Vec<Object>,
/* private fields */
}Expand description
Kubernetes-related attributes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pods: Vec<Pod>Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod.
nodes: Vec<Node>Provides Kubernetes node information.
node_pools: Vec<NodePool>GKE node pools associated with the finding. This field contains node pool information for each node, when it is available.
roles: Vec<Role>Provides Kubernetes role information for findings that involve Roles or ClusterRoles.
bindings: Vec<Binding>Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings.
access_reviews: Vec<AccessReview>Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding.
objects: Vec<Object>Kubernetes objects related to the finding.
Implementations
Sourceimpl Kubernetes
impl Kubernetes
pub fn new() -> Self
Sourcepub fn set_node_pools<T, V>(self, v: T) -> Self
pub fn set_node_pools<T, V>(self, v: T) -> Self
Sets the value of node_pools.
Example
ⓘ
use google_cloud_securitycenter_v2::model::kubernetes::NodePool;
let x = Kubernetes::new()
.set_node_pools([
NodePool::default()/* use setters */,
NodePool::default()/* use (different) setters */,
]);Sourcepub fn set_bindings<T, V>(self, v: T) -> Self
pub fn set_bindings<T, V>(self, v: T) -> Self
Sourcepub fn set_access_reviews<T, V>(self, v: T) -> Self
pub fn set_access_reviews<T, V>(self, v: T) -> Self
Sets the value of access_reviews.
Example
ⓘ
use google_cloud_securitycenter_v2::model::kubernetes::AccessReview;
let x = Kubernetes::new()
.set_access_reviews([
AccessReview::default()/* use setters */,
AccessReview::default()/* use (different) setters */,
]);Sourcepub fn set_objects<T, V>(self, v: T) -> Self
pub fn set_objects<T, V>(self, v: T) -> Self