#[non_exhaustive]pub struct ListResourceValueConfigsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message to list resource value configs of a parent
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns the collection of resource value configs.
Its format is
organizations/[organization_id]
page_size: i32The maximum number of configs to return. The service may return fewer than this value. If unspecified, at most 10 configs will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringA page token, received from a previous ListResourceValueConfigs call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
ListResourceValueConfigs must match the call that provided the
page token.
page_size can be specified, and the new page_size will be used.
Implementations
Sourceimpl ListResourceValueConfigsRequest
impl ListResourceValueConfigsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListResourceValueConfigsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListResourceValueConfigsRequest
impl Clone for ListResourceValueConfigsRequest
Sourcefn clone(&self) -> ListResourceValueConfigsRequest
fn clone(&self) -> ListResourceValueConfigsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListResourceValueConfigsRequest
impl Default for ListResourceValueConfigsRequest
Sourcefn default() -> ListResourceValueConfigsRequest
fn default() -> ListResourceValueConfigsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListResourceValueConfigsRequest
impl PartialEq for ListResourceValueConfigsRequest
Sourcefn eq(&self, other: &ListResourceValueConfigsRequest) -> bool
fn eq(&self, other: &ListResourceValueConfigsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListResourceValueConfigsRequest