#[non_exhaustive]pub struct ListResourceValueConfigsResponse {
pub resource_value_configs: Vec<ResourceValueConfig>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message to list resource value configs
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_value_configs: Vec<ResourceValueConfig>The resource value configs from the specified parent.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is empty, there are no subsequent pages.
Implementations
Sourceimpl ListResourceValueConfigsResponse
impl ListResourceValueConfigsResponse
pub fn new() -> Self
Sourcepub fn set_resource_value_configs<T, V>(self, v: T) -> Self
pub fn set_resource_value_configs<T, V>(self, v: T) -> Self
Sets the value of resource_value_configs.
Example
ⓘ
use google_cloud_securitycenter_v2::model::ResourceValueConfig;
let x = ListResourceValueConfigsResponse::new()
.set_resource_value_configs([
ResourceValueConfig::default()/* use setters */,
ResourceValueConfig::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListResourceValueConfigsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListResourceValueConfigsResponse
impl Clone for ListResourceValueConfigsResponse
Sourcefn clone(&self) -> ListResourceValueConfigsResponse
fn clone(&self) -> ListResourceValueConfigsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListResourceValueConfigsResponse
impl Default for ListResourceValueConfigsResponse
Sourcefn default() -> ListResourceValueConfigsResponse
fn default() -> ListResourceValueConfigsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListResourceValueConfigsResponse
impl PartialEq for ListResourceValueConfigsResponse
Sourcefn eq(&self, other: &ListResourceValueConfigsResponse) -> bool
fn eq(&self, other: &ListResourceValueConfigsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListResourceValueConfigsResponse