#[non_exhaustive]pub struct SecurityMarks {
pub name: String,
pub marks: HashMap<String, String>,
pub canonical_name: String,
/* private fields */
}Expand description
User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization – they can be modified and viewed by all users who have proper permissions on the organization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe relative resource name of the SecurityMarks. See: https://cloud.google.com/apis/design/resource_names#relative_resource_name The following list shows some examples:
organizations/{organization_id}/assets/{asset_id}/securityMarks
organizations/{organization_id}/sources/{source_id}/findings/{finding_id}/securityMarks
+
organizations/{organization_id}/sources/{source_id}/locations/{location}/findings/{finding_id}/securityMarks
marks: HashMap<String, String>Mutable user specified security marks belonging to the parent resource. Constraints are as follows:
- Keys and values are treated as case insensitive
- Keys must be between 1 - 256 characters (inclusive)
- Keys must be letters, numbers, underscores, or dashes
- Values have leading and trailing whitespace trimmed, remaining characters must be between 1 - 4096 characters (inclusive)
canonical_name: StringThe canonical name of the marks. The following list shows some examples:
organizations/{organization_id}/assets/{asset_id}/securityMarks
organizations/{organization_id}/sources/{source_id}/findings/{finding_id}/securityMarks
+
organizations/{organization_id}/sources/{source_id}/locations/{location}/findings/{finding_id}/securityMarks
folders/{folder_id}/assets/{asset_id}/securityMarks
folders/{folder_id}/sources/{source_id}/findings/{finding_id}/securityMarks
+
folders/{folder_id}/sources/{source_id}/locations/{location}/findings/{finding_id}/securityMarks
projects/{project_number}/assets/{asset_id}/securityMarks
projects/{project_number}/sources/{source_id}/findings/{finding_id}/securityMarks
+
projects/{project_number}/sources/{source_id}/locations/{location}/findings/{finding_id}/securityMarks
Implementations
Sourceimpl SecurityMarks
impl SecurityMarks