#[non_exhaustive]pub struct SecurityPolicy {
pub name: String,
pub type: String,
pub preview: bool,
/* private fields */
}Expand description
Information about the Google Cloud Armor security policy relevant to the finding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the Google Cloud Armor security policy, for example, “my-security-policy”.
type: StringThe type of Google Cloud Armor security policy for example, ‘backend security policy’, ‘edge security policy’, ‘network edge security policy’, or ‘always-on DDoS protection’.
preview: boolWhether or not the associated rule or policy is in preview mode.
Implementations