#[non_exhaustive]pub struct UpdateFindingRequest {
pub finding: Option<Finding>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for updating or creating a finding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.finding: Option<Finding>Required. The finding resource to update or create if it does not already exist. parent, security_marks, and update_time will be ignored.
In the case of creation, the finding id portion of the name must be alphanumeric and less than or equal to 32 characters and greater than 0 characters in length.
update_mask: Option<FieldMask>The FieldMask to use when updating the finding resource. This field should not be specified when creating a finding.
When updating a finding, an empty mask is treated as updating all mutable fields and replacing source_properties. Individual source_properties can be added/updated by using “source_properties.<property key>” in the field mask.
Implementations
Sourceimpl UpdateFindingRequest
impl UpdateFindingRequest
Sourcepub fn set_finding<T>(self, v: T) -> Self
pub fn set_finding<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_finding<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_finding<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateFindingRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateFindingRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateFindingRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateFindingRequest
impl Clone for UpdateFindingRequest
Sourcefn clone(&self) -> UpdateFindingRequest
fn clone(&self) -> UpdateFindingRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateFindingRequest
impl Debug for UpdateFindingRequest
Sourceimpl Default for UpdateFindingRequest
impl Default for UpdateFindingRequest
Sourcefn default() -> UpdateFindingRequest
fn default() -> UpdateFindingRequest
Sourceimpl Message for UpdateFindingRequest
impl Message for UpdateFindingRequest
Sourceimpl PartialEq for UpdateFindingRequest
impl PartialEq for UpdateFindingRequest
impl StructuralPartialEq for UpdateFindingRequest