Represents database access information, such as queries. A database may be a
sub-resource of an instance (as in the case of Cloud SQL instances or Cloud
Spanner instances), or the database instance itself. Some database resources
might not have the full resource
name populated because these
resource types, such as Cloud SQL databases, are not yet supported by Cloud
Asset Inventory. In these cases only the display name is provided.
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
Some database resources may not have the full resource
name populated because
these resource types are not yet supported by Cloud Asset Inventory (e.g.
Cloud SQL databases). In these cases only the display name will be
provided.
The full resource name of
the database that the user connected to, if it is supported by Cloud Asset
Inventory.