#[non_exhaustive]pub struct DetectorReference {
pub severity: Severity,
pub detector_id: String,
pub display_name: String,
pub explanation: String,
pub recommendation: String,
/* private fields */
}Expand description
Represents a reference to a specific anomaly detector.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.severity: SeverityThe severity of the detector.
detector_id: StringThe unique identifier of the detector.
display_name: StringA human readable name for the detector, providing context on its purpose. For example, “ASI02: Tool Misuse”, or “Excessive API Calls”.
explanation: StringA detailed explanation generated by an LLM or the detector itself, describing why this specific anomaly was flagged. This provides rationale and context for the detection.
recommendation: StringRecommended steps or actions to remediate or investigate the anomaly flagged by this detector. These could include configuration changes, code adjustments, or further diagnostic procedures.
Implementations
Sourceimpl DetectorReference
impl DetectorReference
Sourcepub fn set_severity<T: Into<Severity>>(self, v: T) -> Self
pub fn set_severity<T: Into<Severity>>(self, v: T) -> Self
Sets the value of severity.
Example
use google_cloud_securitycenter_v2::model::detector_reference::Severity;
let x0 = DetectorReference::new().set_severity(Severity::Critical);
let x1 = DetectorReference::new().set_severity(Severity::High);
let x2 = DetectorReference::new().set_severity(Severity::Medium);Sourcepub fn set_detector_id<T: Into<String>>(self, v: T) -> Self
pub fn set_detector_id<T: Into<String>>(self, v: T) -> Self
Sets the value of detector_id.
Example
let x = DetectorReference::new().set_detector_id("example");Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = DetectorReference::new().set_display_name("example");Sourcepub fn set_explanation<T: Into<String>>(self, v: T) -> Self
pub fn set_explanation<T: Into<String>>(self, v: T) -> Self
Sets the value of explanation.
Example
let x = DetectorReference::new().set_explanation("example");Sourcepub fn set_recommendation<T: Into<String>>(self, v: T) -> Self
pub fn set_recommendation<T: Into<String>>(self, v: T) -> Self
Sets the value of recommendation.
Example
let x = DetectorReference::new().set_recommendation("example");Trait Implementations
Sourceimpl Clone for DetectorReference
impl Clone for DetectorReference
Sourcefn clone(&self) -> DetectorReference
fn clone(&self) -> DetectorReference
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DetectorReference
impl Debug for DetectorReference
Sourceimpl Default for DetectorReference
impl Default for DetectorReference
Sourcefn default() -> DetectorReference
fn default() -> DetectorReference
Sourceimpl Message for DetectorReference
impl Message for DetectorReference
Sourceimpl PartialEq for DetectorReference
impl PartialEq for DetectorReference
impl StructuralPartialEq for DetectorReference